==> 0.0.4.tar.gz: lib/package/base.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class Millui {
  static left(double value) {
    return EdgeInsets.only(left: value);
  }

  static right(double value) {
    return EdgeInsets.only(right: value);
  }

  static top(double value) {
    return EdgeInsets.only(top: value);
  }

  static bottom(double value) {
    return EdgeInsets.only(bottom: value);
  }

  static padding(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return EdgeInsets.all(a);
    }

    if (c == null && d == null && b != null) {
      return EdgeInsets.symmetric(vertical: a, horizontal: b);
    }

    if (b != null && c != null && d == null) {
      return EdgeInsets.only(left: b, right: b, top: a, bottom: c);
    }

    if (b != null && c != null && d != null) {
      return EdgeInsets.only(top: a, right: b, bottom: c, left: b);
    }
  }

  static margin(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return EdgeInsets.all(a);
    }

    if (c == null && d == null && b != null) {
      return EdgeInsets.symmetric(vertical: a, horizontal: b);
    }

    if (b != null && c != null && d == null) {
      return EdgeInsets.only(left: b, right: b, top: a, bottom: c);
    }

    if (b != null && c != null && d != null) {
      return EdgeInsets.only(top: a, right: b, bottom: c, left: b);
    }
  }

  static border(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border.all(
      width: width,
      color: color,
      style: style,
    );
  }

  static borderRight(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      right: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderLeft(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      left: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderTop(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      top: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderBottom(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      bottom: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderRadio(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return BorderRadius.circular(a);
    }

    if (c == null && d == null && b != null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(a),
        bottomLeft: Radius.circular(b),
      );
    }

    if (b != null && c != null && d == null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(c),
        bottomLeft: Radius.circular(b),
      );
    }

    if (b != null && c != null && d != null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(c),
        bottomLeft: Radius.circular(d),
      );
    }
  }

  static getBatteryLevel() async {
    const platform = const MethodChannel('millui');
    return platform.invokeMethod('getBatteryLevel');
  }
}

==> 0.0.6.tar.gz: lib/package/base.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class Millui {
  static left(double value) {
    return EdgeInsets.only(left: value);
  }

  static right(double value) {
    return EdgeInsets.only(right: value);
  }

  static top(double value) {
    return EdgeInsets.only(top: value);
  }

  static bottom(double value) {
    return EdgeInsets.only(bottom: value);
  }

  static padding(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return EdgeInsets.all(a);
    }

    if (c == null && d == null && b != null) {
      return EdgeInsets.symmetric(vertical: a, horizontal: b);
    }

    if (b != null && c != null && d == null) {
      return EdgeInsets.only(left: b, right: b, top: a, bottom: c);
    }

    if (b != null && c != null && d != null) {
      return EdgeInsets.only(top: a, right: b, bottom: c, left: d);
    }
  }

  static margin(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return EdgeInsets.all(a);
    }

    if (c == null && d == null && b != null) {
      return EdgeInsets.symmetric(vertical: a, horizontal: b);
    }

    if (b != null && c != null && d == null) {
      return EdgeInsets.only(left: b, right: b, top: a, bottom: c);
    }

    if (b != null && c != null && d != null) {
      return EdgeInsets.only(top: a, right: b, bottom: c, left: d);
    }
  }

  static border(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border.all(
      width: width,
      color: color,
      style: style,
    );
  }

  static borderRight(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      right: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderLeft(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      left: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderTop(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      top: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderBottom(double width, Color color,
      [BorderStyle style = BorderStyle.solid]) {
    return Border(
      bottom: BorderSide(
        width: width,
        color: color,
        style: style,
      ),
    );
  }

  static borderRadio(double a, [double b, double c, double d]) {
    if (c == null && d == null && b == null) {
      return BorderRadius.circular(a);
    }

    if (c == null && d == null && b != null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(a),
        bottomLeft: Radius.circular(b),
      );
    }

    if (b != null && c != null && d == null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(c),
        bottomLeft: Radius.circular(b),
      );
    }

    if (b != null && c != null && d != null) {
      return BorderRadius.only(
        topLeft: Radius.circular(a),
        topRight: Radius.circular(b),
        bottomRight: Radius.circular(c),
        bottomLeft: Radius.circular(d),
      );
    }
  }

  static getBatteryLevel() async {
    const platform = const MethodChannel('millui');
    return platform.invokeMethod('getBatteryLevel');
  }
}
